"""
Google Maps Places Example: https://developers.google.com/places/web-service/search

1. Get an API Key. Follow steps here: 
   https://developers.google.com/places/web-service/get-api-key
   
   When you go to Credentials, don't worry about the authorized IPs, leave it
   blank and click continue. Your API Key should pop up in a dialog on the next page.
   
   If you already have a Google Developer KEY for some other service, you have
   to enable Google Places. Do this by going to this link:
        https://console.developers.google.com/apis/library?project=pacific-smile-112416
   and clicking on the API you want to authorize (Google Maps Places in this case)

2. Study the API at: https://developers.google.com/places/web-service/search

3. Construct a URL with the required parameters of:
       key, location, radius

4. Optionally filter by type, for instance, type="food"

5. Get the data and have fun using these live data!

In this example I find all the food places withing 3 miles of CMU
"""

import urllib.parse

SECRET_KEY = "ENTER YOUR API KEY HERE"
BASE_URL = "https://maps.googleapis.com/maps/api/place/nearbysearch/json?"
CMU_LAT_LONG = "40.442632,-79.942127"

params = {}
params["key"] = SECRET_KEY
params["location"] = CMU_LAT_LONG # must be "lat,long"
params["radius"] = "5000" # radius in meters, so this is 5km radius
params["types"] = "food"

def getDataFromURL(base_url, options):
  import urllib.request
  import urllib.parse
  import json
  
  data = None
  params_str = urllib.parse.urlencode(params)
  request_url = base_url + params_str
  request = urllib.request.Request(request_url)
  with urllib.request.urlopen(request_url) as response:
    # first read the response from the response object
    data = response.read()
    # now decode it from bytes to string
    data = data.decode("utf-8")
    # now parse the string into a python object of dictionaries and lists
    data = json.loads(data)
  return data

data = getDataFromURL(BASE_URL, params)

for result in data["results"]:
  print(result["name"])
